index\_calculator.index\_calculator
===================================

.. currentmodule:: index_calculator

.. autoclass:: index_calculator


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~index_calculator.__init__
      ~index_calculator.compute
